==> plee-the-bear_0.4.1.orig.tar.gz: plee-the-bear-0.4.1/plee-the-bear/src/ptb/frame/frame_pause.hpp <==
/*
  Plee the Bear

  Copyright (C) 2005-2009 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [PTB] in the subject of your mails.
*/
/**
 * \file frame_pause.hpp
 * \brief This frame is shown when the game is paused.
 * \author Julien Jorge
 */
#ifndef __PTB_FRAME_PAUSE_HPP__
#define __PTB_FRAME_PAUSE_HPP__

#include "ptb/frame/menu_frame.hpp"

namespace ptb
{
  /**
   * \brief This frame is shown when the game is paused.
   * \author Julien Jorge
   */
  class frame_pause : public menu_frame
  {
  public:
    frame_pause( windows_layer* in_layer );

  private:
    bool on_close();

    void quit() const;
    void validate() const;

    void create_controls();

  private:
    /**
     * \name Actions in the menu.
     * The positions of the actions in the menu.
     */
    /** \{ */
    static const unsigned int s_pos_resume;
    static const unsigned int s_pos_configure;
    static const unsigned int s_pos_title_screen;
    /** \} */

  }; // class frame_pause
} // namespace ptb

#endif // __PTB_FRAME_PAUSE_HPP__

==> plee-the-bear_0.5.1.orig.tar.gz: plee-the-bear-0.5.1/plee-the-bear/src/ptb/frame/frame_pause.hpp <==
/*
  Plee the Bear

  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [PTB] in the subject of your mails.
*/
/**
 * \file frame_pause.hpp
 * \brief This frame is shown when the game is paused.
 * \author Julien Jorge
 */
#ifndef __PTB_FRAME_PAUSE_HPP__
#define __PTB_FRAME_PAUSE_HPP__

#include "ptb/frame/menu_frame.hpp"
#include "ptb/frame/message_box.hpp"

namespace ptb
{
  /**
   * \brief This frame is shown when the game is paused.
   * \author Julien Jorge
   */
  class frame_pause:
    public menu_frame
  {
  public:
    frame_pause( windows_layer* in_layer );

  private:
    bool on_close();
    void on_focus();

    void on_resume() const;
    void on_title_screen();
    void on_configuration();

    void create_controls();

  private:
    /** \brief The resulting value of a displayed message box. */
    message_box::flags m_msg_result;

  }; // class frame_pause
} // namespace ptb

#endif // __PTB_FRAME_PAUSE_HPP__
